"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ProjReply(google.protobuf.message.Message):
    """投屏"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CMD_TYPE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    VIDEO_TYPE_FIELD_NUMBER: builtins.int
    EP_ID_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    SEEK_TS_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    cmd_type: builtins.int
    """投屏命令
    1:起播 2:快进 3:快退 4:seek播放进度 5:暂停 6:暂停恢复
    """
    mid: builtins.int
    """用户id"""
    aid: builtins.int
    """稿件id"""
    cid: builtins.int
    """视频id"""
    video_type: builtins.int
    """视频类型
    0:ugc 1:pgc 2:pugv
    """
    ep_id: builtins.int
    """单集id，pgc和pugv需要传"""
    season_id: builtins.int
    """剧集id"""
    seek_ts: builtins.int
    """seek 的位置，cmd位seek时有值，单位秒"""
    extra: builtins.str
    """其他指令对应内容"""
    def __init__(
        self,
        *,
        cmd_type: builtins.int = ...,
        mid: builtins.int = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        video_type: builtins.int = ...,
        ep_id: builtins.int = ...,
        season_id: builtins.int = ...,
        seek_ts: builtins.int = ...,
        extra: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "cmd_type", b"cmd_type", "ep_id", b"ep_id", "extra", b"extra", "mid", b"mid", "season_id", b"season_id", "seek_ts", b"seek_ts", "video_type", b"video_type"]) -> None: ...

global___ProjReply = ProjReply

@typing_extensions.final
class LiveStatusNotify(google.protobuf.message.Message):
    """直播状态"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    status: builtins.int
    """直播状态
    1:开播 2:关播 3:截流 4:截流恢复
    """
    msg: builtins.str
    """文案"""
    cid: builtins.int
    """直播房间号"""
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        msg: builtins.str = ...,
        cid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "msg", b"msg", "status", b"status"]) -> None: ...

global___LiveStatusNotify = LiveStatusNotify

@typing_extensions.final
class EsportsNotify(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CID_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """直播房间号"""
    def __init__(
        self,
        *,
        cid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid"]) -> None: ...

global___EsportsNotify = EsportsNotify

@typing_extensions.final
class PublicityNotify(google.protobuf.message.Message):
    """直播插卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLICITY_ID_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    publicity_id: builtins.int
    """插卡id"""
    room_id: builtins.int
    """直播房间号"""
    status: builtins.int
    """直播间状态
    0:未开播 1:直播中 2:轮播中
    """
    def __init__(
        self,
        *,
        publicity_id: builtins.int = ...,
        room_id: builtins.int = ...,
        status: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["publicity_id", b"publicity_id", "room_id", b"room_id", "status", b"status"]) -> None: ...

global___PublicityNotify = PublicityNotify

@typing_extensions.final
class LiveSkipNotify(google.protobuf.message.Message):
    """直转点"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIVE_ID_FIELD_NUMBER: builtins.int
    live_id: builtins.int
    """直播id"""
    def __init__(
        self,
        *,
        live_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["live_id", b"live_id"]) -> None: ...

global___LiveSkipNotify = LiveSkipNotify



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.wall.v1 import wall_pb2 as bilibili_dot_app_dot_wall_dot_v1_dot_wall__pb2


class WallStub(object):
    """免流规则
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RuleInfo = channel.unary_unary(
                '/bilibili.app.wall.v1.Wall/RuleInfo',
                request_serializer=bilibili_dot_app_dot_wall_dot_v1_dot_wall__pb2.RuleRequest.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_wall_dot_v1_dot_wall__pb2.RulesReply.FromString,
                )


class WallServicer(object):
    """免流规则
    """

    def RuleInfo(self, request, context):
        """获取免流规则信息
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WallServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RuleInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.RuleInfo,
                    request_deserializer=bilibili_dot_app_dot_wall_dot_v1_dot_wall__pb2.RuleRequest.FromString,
                    response_serializer=bilibili_dot_app_dot_wall_dot_v1_dot_wall__pb2.RulesReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.wall.v1.Wall', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Wall(object):
    """免流规则
    """

    @staticmethod
    def RuleInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.wall.v1.Wall/RuleInfo',
            bilibili_dot_app_dot_wall_dot_v1_dot_wall__pb2.RuleRequest.SerializeToString,
            bilibili_dot_app_dot_wall_dot_v1_dot_wall__pb2.RulesReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AddParams(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    A_FIELD_NUMBER: builtins.int
    B_FIELD_NUMBER: builtins.int
    a: builtins.int
    """"""
    b: builtins.int
    """"""
    def __init__(
        self,
        *,
        a: builtins.int = ...,
        b: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["a", b"a", "b", b"b"]) -> None: ...

global___AddParams = AddParams

@typing_extensions.final
class AddResult(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    R_FIELD_NUMBER: builtins.int
    r: builtins.int
    """"""
    def __init__(
        self,
        *,
        r: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["r", b"r"]) -> None: ...

global___AddResult = AddResult

@typing_extensions.final
class TestResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASKID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    taskid: builtins.int
    """任务id"""
    timestamp: builtins.int
    """时间戳"""
    message: builtins.str
    """消息"""
    @property
    def extra(self) -> google.protobuf.any_pb2.Any:
        """扩展"""
    def __init__(
        self,
        *,
        taskid: builtins.int = ...,
        timestamp: builtins.int = ...,
        message: builtins.str = ...,
        extra: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extra", b"extra"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["extra", b"extra", "message", b"message", "taskid", b"taskid", "timestamp", b"timestamp"]) -> None: ...

global___TestResp = TestResp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/dagw/component/avatar/v1/plugin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.dagw.component.avatar.common import common_pb2 as bilibili_dot_dagw_dot_component_dot_avatar_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.bilibili/dagw/component/avatar/v1/plugin.proto\x12(bilibili.dagw.component.avatar.v1.plugin\x1a\x32\x62ilibili/dagw/component/avatar/common/common.proto\"\x7f\n\x18\x43ommentDoubleClickConfig\x12J\n\x0binteraction\x18\x01 \x01(\x0b\x32\x35.bilibili.dagw.component.avatar.v1.plugin.Interaction\x12\x17\n\x0f\x61nimation_scale\x18\x02 \x01(\x01\"U\n\nGyroConfig\x12G\n\tgyroscope\x18\x01 \x01(\x0b\x32\x34.bilibili.dagw.component.avatar.v1.plugin.NFTImageV2\"\x94\x01\n\x12GyroscopeContentV2\x12\x10\n\x08\x66ile_url\x18\x01 \x01(\t\x12\r\n\x05scale\x18\x02 \x01(\x02\x12]\n\x14physical_orientation\x18\x03 \x03(\x0b\x32?.bilibili.dagw.component.avatar.v1.plugin.PhysicalOrientationV2\"y\n\x11GyroscopeEntityV2\x12\x14\n\x0c\x64isplay_type\x18\x01 \x01(\t\x12N\n\x08\x63ontents\x18\x02 \x03(\x0b\x32<.bilibili.dagw.component.avatar.v1.plugin.GyroscopeContentV2\"S\n\x0bInteraction\x12\x0e\n\x06nft_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\r\n\x05itype\x18\x03 \x01(\t\x12\x14\n\x0cmetadata_url\x18\x04 \x01(\t\"\"\n\x0fLiveAnimeConfig\x12\x0f\n\x07is_live\x18\x01 \x01(\x08\"\xb6\x01\n\rLiveAnimeItem\x12\x41\n\x05\x63olor\x18\x01 \x01(\x0b\x32\x32.bilibili.dagw.component.avatar.common.ColorConfig\x12\x13\n\x0bstart_ratio\x18\x02 \x01(\x01\x12\x11\n\tend_ratio\x18\x03 \x01(\x01\x12\x14\n\x0cstart_stroke\x18\x04 \x01(\x01\x12\x15\n\rstart_opacity\x18\x05 \x01(\x01\x12\r\n\x05phase\x18\x06 \x01(\x03\"\\\n\nNFTImageV2\x12N\n\tgyroscope\x18\x01 \x03(\x0b\x32;.bilibili.dagw.component.avatar.v1.plugin.GyroscopeEntityV2\"<\n\x1cPhysicalOrientationAnimation\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06\x62\x65zier\x18\x03 \x01(\t\"\x81\x01\n\x15PhysicalOrientationV2\x12\x0c\n\x04type\x18\x01 \x01(\t\x12Z\n\nanimations\x18\x03 \x03(\x0b\x32\x46.bilibili.dagw.component.avatar.v1.plugin.PhysicalOrientationAnimationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.dagw.component.avatar.v1.plugin_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMMENTDOUBLECLICKCONFIG']._serialized_start=144
  _globals['_COMMENTDOUBLECLICKCONFIG']._serialized_end=271
  _globals['_GYROCONFIG']._serialized_start=273
  _globals['_GYROCONFIG']._serialized_end=358
  _globals['_GYROSCOPECONTENTV2']._serialized_start=361
  _globals['_GYROSCOPECONTENTV2']._serialized_end=509
  _globals['_GYROSCOPEENTITYV2']._serialized_start=511
  _globals['_GYROSCOPEENTITYV2']._serialized_end=632
  _globals['_INTERACTION']._serialized_start=634
  _globals['_INTERACTION']._serialized_end=717
  _globals['_LIVEANIMECONFIG']._serialized_start=719
  _globals['_LIVEANIMECONFIG']._serialized_end=753
  _globals['_LIVEANIMEITEM']._serialized_start=756
  _globals['_LIVEANIMEITEM']._serialized_end=938
  _globals['_NFTIMAGEV2']._serialized_start=940
  _globals['_NFTIMAGEV2']._serialized_end=1032
  _globals['_PHYSICALORIENTATIONANIMATION']._serialized_start=1034
  _globals['_PHYSICALORIENTATIONANIMATION']._serialized_end=1094
  _globals['_PHYSICALORIENTATIONV2']._serialized_start=1097
  _globals['_PHYSICALORIENTATIONV2']._serialized_end=1226
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RegionConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCENES_NAME_FIELD_NUMBER: builtins.int
    SCENES_TYPE_FIELD_NUMBER: builtins.int
    scenes_name: builtins.str
    """"""
    scenes_type: builtins.str
    """"""
    def __init__(
        self,
        *,
        scenes_name: builtins.str = ...,
        scenes_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["scenes_name", b"scenes_name", "scenes_type", b"scenes_type"]) -> None: ...

global___RegionConfig = RegionConfig

@typing_extensions.final
class RegionInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TID_FIELD_NUMBER: builtins.int
    REID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOGO_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    IS_BANGUMI_FIELD_NUMBER: builtins.int
    CHILDREN_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    tid: builtins.int
    """"""
    reid: builtins.int
    """"""
    name: builtins.str
    """"""
    logo: builtins.str
    """"""
    goto: builtins.str
    """"""
    param: builtins.str
    """"""
    uri: builtins.str
    """"""
    type: builtins.int
    """"""
    is_bangumi: builtins.int
    """"""
    @property
    def children(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegionInfo]:
        """"""
    @property
    def config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegionConfig]:
        """"""
    def __init__(
        self,
        *,
        tid: builtins.int = ...,
        reid: builtins.int = ...,
        name: builtins.str = ...,
        logo: builtins.str = ...,
        goto: builtins.str = ...,
        param: builtins.str = ...,
        uri: builtins.str = ...,
        type: builtins.int = ...,
        is_bangumi: builtins.int = ...,
        children: collections.abc.Iterable[global___RegionInfo] | None = ...,
        config: collections.abc.Iterable[global___RegionConfig] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["children", b"children", "config", b"config", "goto", b"goto", "is_bangumi", b"is_bangumi", "logo", b"logo", "name", b"name", "param", b"param", "reid", b"reid", "tid", b"tid", "type", b"type", "uri", b"uri"]) -> None: ...

global___RegionInfo = RegionInfo

@typing_extensions.final
class RegionReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGIONS_FIELD_NUMBER: builtins.int
    @property
    def regions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegionInfo]:
        """"""
    def __init__(
        self,
        *,
        regions: collections.abc.Iterable[global___RegionInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["regions", b"regions"]) -> None: ...

global___RegionReply = RegionReply

@typing_extensions.final
class RegionReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANG_FIELD_NUMBER: builtins.int
    lang: builtins.str
    """"""
    def __init__(
        self,
        *,
        lang: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lang", b"lang"]) -> None: ...

global___RegionReq = RegionReq



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.card.v1.common_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DoubleCards(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SMALL_COVER_V2_FIELD_NUMBER: builtins.int
    ONE_PIC_V2_FIELD_NUMBER: builtins.int
    THREE_PIC_V2_FIELD_NUMBER: builtins.int
    @property
    def small_cover_v2(self) -> global___SmallCoverV2:
        """"""
    @property
    def one_pic_v2(self) -> global___OnePicV2:
        """"""
    @property
    def three_pic_v2(self) -> global___ThreePicV2:
        """"""
    def __init__(
        self,
        *,
        small_cover_v2: global___SmallCoverV2 | None = ...,
        one_pic_v2: global___OnePicV2 | None = ...,
        three_pic_v2: global___ThreePicV2 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["Card", b"Card", "one_pic_v2", b"one_pic_v2", "small_cover_v2", b"small_cover_v2", "three_pic_v2", b"three_pic_v2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["Card", b"Card", "one_pic_v2", b"one_pic_v2", "small_cover_v2", b"small_cover_v2", "three_pic_v2", b"three_pic_v2"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["Card", b"Card"]) -> typing_extensions.Literal["small_cover_v2", "one_pic_v2", "three_pic_v2"] | None: ...

global___DoubleCards = DoubleCards

@typing_extensions.final
class SmallCoverV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    COVER_GIF_FIELD_NUMBER: builtins.int
    COVER_BLUR_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_2_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_ICON_FIELD_NUMBER: builtins.int
    COVER_RIGHT_BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    OFFICIAL_ICON_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_V2_FIELD_NUMBER: builtins.int
    LIKE_BUTTON_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    cover_gif: builtins.str
    """"""
    cover_blur: builtins.int
    """"""
    cover_left_text_1: builtins.str
    """"""
    cover_left_icon_1: builtins.int
    """"""
    cover_left_text_2: builtins.str
    """"""
    cover_left_icon_2: builtins.int
    """"""
    cover_right_text: builtins.str
    """"""
    cover_right_icon: builtins.int
    """"""
    cover_right_background_color: builtins.str
    """"""
    subtitle: builtins.str
    """"""
    badge: builtins.str
    """"""
    rcmd_reason: builtins.str
    """"""
    desc: builtins.str
    """"""
    @property
    def avatar(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Avatar:
        """"""
    official_icon: builtins.int
    """"""
    can_play: builtins.int
    """"""
    @property
    def rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    @property
    def rcmd_reason_style_v2(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    @property
    def like_button(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.LikeButton:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        cover_gif: builtins.str = ...,
        cover_blur: builtins.int = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_icon_2: builtins.int = ...,
        cover_right_text: builtins.str = ...,
        cover_right_icon: builtins.int = ...,
        cover_right_background_color: builtins.str = ...,
        subtitle: builtins.str = ...,
        badge: builtins.str = ...,
        rcmd_reason: builtins.str = ...,
        desc: builtins.str = ...,
        avatar: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Avatar | None = ...,
        official_icon: builtins.int = ...,
        can_play: builtins.int = ...,
        rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        rcmd_reason_style_v2: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        like_button: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.LikeButton | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "base", b"base", "like_button", b"like_button", "rcmd_reason_style", b"rcmd_reason_style", "rcmd_reason_style_v2", b"rcmd_reason_style_v2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "badge", b"badge", "base", b"base", "can_play", b"can_play", "cover_blur", b"cover_blur", "cover_gif", b"cover_gif", "cover_left_icon_1", b"cover_left_icon_1", "cover_left_icon_2", b"cover_left_icon_2", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_right_background_color", b"cover_right_background_color", "cover_right_icon", b"cover_right_icon", "cover_right_text", b"cover_right_text", "desc", b"desc", "like_button", b"like_button", "official_icon", b"official_icon", "rcmd_reason", b"rcmd_reason", "rcmd_reason_style", b"rcmd_reason_style", "rcmd_reason_style_v2", b"rcmd_reason_style_v2", "subtitle", b"subtitle"]) -> None: ...

global___SmallCoverV2 = SmallCoverV2

@typing_extensions.final
class SmallCoverV3(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_BUTTON_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    OFFICIAL_ICON_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    @property
    def avatar(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Avatar:
        """"""
    cover_left_text: builtins.str
    """"""
    @property
    def cover_right_button(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Button:
        """"""
    rcmd_reason: builtins.str
    """"""
    desc: builtins.str
    """"""
    official_icon: builtins.int
    """"""
    can_play: builtins.int
    """"""
    @property
    def rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        avatar: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Avatar | None = ...,
        cover_left_text: builtins.str = ...,
        cover_right_button: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Button | None = ...,
        rcmd_reason: builtins.str = ...,
        desc: builtins.str = ...,
        official_icon: builtins.int = ...,
        can_play: builtins.int = ...,
        rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "base", b"base", "cover_right_button", b"cover_right_button", "rcmd_reason_style", b"rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "base", b"base", "can_play", b"can_play", "cover_left_text", b"cover_left_text", "cover_right_button", b"cover_right_button", "desc", b"desc", "official_icon", b"official_icon", "rcmd_reason", b"rcmd_reason", "rcmd_reason_style", b"rcmd_reason_style"]) -> None: ...

global___SmallCoverV3 = SmallCoverV3

@typing_extensions.final
class MiddleCoverV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    RATIO_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    ratio: builtins.int
    """"""
    desc: builtins.str
    """"""
    badge: builtins.str
    """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        ratio: builtins.int = ...,
        desc: builtins.str = ...,
        badge: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "base", b"base", "desc", b"desc", "ratio", b"ratio"]) -> None: ...

global___MiddleCoverV2 = MiddleCoverV2

@typing_extensions.final
class LargeCoverV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    COVER_RIGHT_BUTTON_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_2_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    OFFICIAL_ICON_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    SHOW_TOP_FIELD_NUMBER: builtins.int
    SHOW_BOTTOM_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    @property
    def avatar(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Avatar:
        """"""
    badge: builtins.str
    """"""
    @property
    def cover_right_button(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Button:
        """"""
    cover_left_text_1: builtins.str
    """"""
    cover_left_icon_1: builtins.int
    """"""
    cover_left_text_2: builtins.str
    """"""
    cover_left_icon_2: builtins.int
    """"""
    rcmd_reason: builtins.str
    """"""
    official_icon: builtins.int
    """"""
    can_play: builtins.int
    """"""
    @property
    def rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    show_top: builtins.int
    """"""
    show_bottom: builtins.int
    """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        avatar: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Avatar | None = ...,
        badge: builtins.str = ...,
        cover_right_button: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Button | None = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_icon_2: builtins.int = ...,
        rcmd_reason: builtins.str = ...,
        official_icon: builtins.int = ...,
        can_play: builtins.int = ...,
        rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        show_top: builtins.int = ...,
        show_bottom: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "base", b"base", "cover_right_button", b"cover_right_button", "rcmd_reason_style", b"rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "badge", b"badge", "base", b"base", "can_play", b"can_play", "cover_left_icon_1", b"cover_left_icon_1", "cover_left_icon_2", b"cover_left_icon_2", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_right_button", b"cover_right_button", "official_icon", b"official_icon", "rcmd_reason", b"rcmd_reason", "rcmd_reason_style", b"rcmd_reason_style", "show_bottom", b"show_bottom", "show_top", b"show_top"]) -> None: ...

global___LargeCoverV2 = LargeCoverV2

@typing_extensions.final
class ThreeItemV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    TITLE_ICON_FIELD_NUMBER: builtins.int
    MORE_URI_FIELD_NUMBER: builtins.int
    MORE_TEXT_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    title_icon: builtins.int
    """"""
    more_uri: builtins.str
    """"""
    more_text: builtins.str
    """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreeItemV2Item]:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        title_icon: builtins.int = ...,
        more_uri: builtins.str = ...,
        more_text: builtins.str = ...,
        items: collections.abc.Iterable[global___ThreeItemV2Item] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "items", b"items", "more_text", b"more_text", "more_uri", b"more_uri", "title_icon", b"title_icon"]) -> None: ...

global___ThreeItemV2 = ThreeItemV2

@typing_extensions.final
class ThreeItemV2Item(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_FIELD_NUMBER: builtins.int
    DESC_TEXT_1_FIELD_NUMBER: builtins.int
    DESC_ICON_1_FIELD_NUMBER: builtins.int
    DESC_TEXT_2_FIELD_NUMBER: builtins.int
    DESC_ICON_2_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    cover_left_icon: builtins.int
    """"""
    desc_text_1: builtins.str
    """"""
    desc_icon_1: builtins.int
    """"""
    desc_text_2: builtins.str
    """"""
    desc_icon_2: builtins.int
    """"""
    badge: builtins.str
    """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        cover_left_icon: builtins.int = ...,
        desc_text_1: builtins.str = ...,
        desc_icon_1: builtins.int = ...,
        desc_text_2: builtins.str = ...,
        desc_icon_2: builtins.int = ...,
        badge: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "base", b"base", "cover_left_icon", b"cover_left_icon", "desc_icon_1", b"desc_icon_1", "desc_icon_2", b"desc_icon_2", "desc_text_1", b"desc_text_1", "desc_text_2", b"desc_text_2"]) -> None: ...

global___ThreeItemV2Item = ThreeItemV2Item

@typing_extensions.final
class SmallCoverV4(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    COVER_BADGE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    TITLE_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    TITLE_RIGHT_PIC_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    cover_badge: builtins.str
    """"""
    desc: builtins.str
    """"""
    title_right_text: builtins.str
    """"""
    title_right_pic: builtins.int
    """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        cover_badge: builtins.str = ...,
        desc: builtins.str = ...,
        title_right_text: builtins.str = ...,
        title_right_pic: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "cover_badge", b"cover_badge", "desc", b"desc", "title_right_pic", b"title_right_pic", "title_right_text", b"title_right_text"]) -> None: ...

global___SmallCoverV4 = SmallCoverV4

@typing_extensions.final
class TwoItemV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TwoItemV2Item]:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        items: collections.abc.Iterable[global___TwoItemV2Item] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "items", b"items"]) -> None: ...

global___TwoItemV2 = TwoItemV2

@typing_extensions.final
class TwoItemV2Item(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    badge: builtins.str
    """"""
    cover_left_text_1: builtins.str
    """"""
    cover_left_icon_1: builtins.int
    """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        badge: builtins.str = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_icon_1: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "base", b"base", "cover_left_icon_1", b"cover_left_icon_1", "cover_left_text_1", b"cover_left_text_1"]) -> None: ...

global___TwoItemV2Item = TwoItemV2Item

@typing_extensions.final
class MultiItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    MORE_URI_FIELD_NUMBER: builtins.int
    MORE_TEXT_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    more_uri: builtins.str
    """"""
    more_text: builtins.str
    """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DoubleCards]:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        more_uri: builtins.str = ...,
        more_text: builtins.str = ...,
        items: collections.abc.Iterable[global___DoubleCards] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "items", b"items", "more_text", b"more_text", "more_uri", b"more_uri"]) -> None: ...

global___MultiItem = MultiItem

@typing_extensions.final
class ThreePicV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    LEFT_COVER_FIELD_NUMBER: builtins.int
    RIGHT_COVER_1_FIELD_NUMBER: builtins.int
    RIGHT_COVER_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_2_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_ICON_FIELD_NUMBER: builtins.int
    COVER_RIGHT_BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    left_cover: builtins.str
    """"""
    right_cover_1: builtins.str
    """"""
    right_cover_2: builtins.str
    """"""
    cover_left_text_1: builtins.str
    """"""
    cover_left_icon_1: builtins.int
    """"""
    cover_left_text_2: builtins.str
    """"""
    cover_left_icon_2: builtins.int
    """"""
    cover_right_text: builtins.str
    """"""
    cover_right_icon: builtins.int
    """"""
    cover_right_background_color: builtins.str
    """"""
    badge: builtins.str
    """"""
    rcmd_reason: builtins.str
    """"""
    desc: builtins.str
    """"""
    @property
    def avatar(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Avatar:
        """"""
    @property
    def rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        left_cover: builtins.str = ...,
        right_cover_1: builtins.str = ...,
        right_cover_2: builtins.str = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_icon_2: builtins.int = ...,
        cover_right_text: builtins.str = ...,
        cover_right_icon: builtins.int = ...,
        cover_right_background_color: builtins.str = ...,
        badge: builtins.str = ...,
        rcmd_reason: builtins.str = ...,
        desc: builtins.str = ...,
        avatar: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Avatar | None = ...,
        rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "base", b"base", "rcmd_reason_style", b"rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "badge", b"badge", "base", b"base", "cover_left_icon_1", b"cover_left_icon_1", "cover_left_icon_2", b"cover_left_icon_2", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_right_background_color", b"cover_right_background_color", "cover_right_icon", b"cover_right_icon", "cover_right_text", b"cover_right_text", "desc", b"desc", "left_cover", b"left_cover", "rcmd_reason", b"rcmd_reason", "rcmd_reason_style", b"rcmd_reason_style", "right_cover_1", b"right_cover_1", "right_cover_2", b"right_cover_2"]) -> None: ...

global___ThreePicV2 = ThreePicV2

@typing_extensions.final
class OnePicV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_ICON_FIELD_NUMBER: builtins.int
    COVER_RIGHT_BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    cover_left_icon_1: builtins.int
    """"""
    cover_left_text_2: builtins.str
    """"""
    cover_right_text: builtins.str
    """"""
    cover_right_icon: builtins.int
    """"""
    cover_right_background_color: builtins.str
    """"""
    badge: builtins.str
    """"""
    rcmd_reason: builtins.str
    """"""
    @property
    def avatar(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Avatar:
        """"""
    @property
    def rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: builtins.str = ...,
        cover_right_text: builtins.str = ...,
        cover_right_icon: builtins.int = ...,
        cover_right_background_color: builtins.str = ...,
        badge: builtins.str = ...,
        rcmd_reason: builtins.str = ...,
        avatar: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Avatar | None = ...,
        rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "base", b"base", "rcmd_reason_style", b"rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "badge", b"badge", "base", b"base", "cover_left_icon_1", b"cover_left_icon_1", "cover_left_text_2", b"cover_left_text_2", "cover_right_background_color", b"cover_right_background_color", "cover_right_icon", b"cover_right_icon", "cover_right_text", b"cover_right_text", "rcmd_reason", b"rcmd_reason", "rcmd_reason_style", b"rcmd_reason_style"]) -> None: ...

global___OnePicV2 = OnePicV2

@typing_extensions.final
class LargeCoverV3(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    COVER_GIF_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    TOP_RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    BOTTOM_RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_2_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    OFFICIAL_ICON_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    cover_gif: builtins.str
    """"""
    @property
    def avatar(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Avatar:
        """"""
    @property
    def top_rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    @property
    def bottom_rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    cover_left_text_1: builtins.str
    """"""
    cover_left_icon_1: builtins.int
    """"""
    cover_left_text_2: builtins.str
    """"""
    cover_left_icon_2: builtins.int
    """"""
    cover_right_text: builtins.str
    """"""
    desc: builtins.str
    """"""
    official_icon: builtins.int
    """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        cover_gif: builtins.str = ...,
        avatar: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Avatar | None = ...,
        top_rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        bottom_rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_icon_2: builtins.int = ...,
        cover_right_text: builtins.str = ...,
        desc: builtins.str = ...,
        official_icon: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "base", b"base", "bottom_rcmd_reason_style", b"bottom_rcmd_reason_style", "top_rcmd_reason_style", b"top_rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "base", b"base", "bottom_rcmd_reason_style", b"bottom_rcmd_reason_style", "cover_gif", b"cover_gif", "cover_left_icon_1", b"cover_left_icon_1", "cover_left_icon_2", b"cover_left_icon_2", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_right_text", b"cover_right_text", "desc", b"desc", "official_icon", b"official_icon", "top_rcmd_reason_style", b"top_rcmd_reason_style"]) -> None: ...

global___LargeCoverV3 = LargeCoverV3

@typing_extensions.final
class ThreePicV3(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    LEFT_COVER_FIELD_NUMBER: builtins.int
    RIGHT_COVER_1_FIELD_NUMBER: builtins.int
    RIGHT_COVER_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_2_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_ICON_FIELD_NUMBER: builtins.int
    COVER_RIGHT_BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    left_cover: builtins.str
    """"""
    right_cover_1: builtins.str
    """"""
    right_cover_2: builtins.str
    """"""
    cover_left_text_1: builtins.str
    """"""
    cover_left_icon_1: builtins.int
    """"""
    cover_left_text_2: builtins.str
    """"""
    cover_left_icon_2: builtins.int
    """"""
    cover_right_text: builtins.str
    """"""
    cover_right_icon: builtins.int
    """"""
    cover_right_background_color: builtins.str
    """"""
    badge: builtins.str
    """"""
    @property
    def rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        left_cover: builtins.str = ...,
        right_cover_1: builtins.str = ...,
        right_cover_2: builtins.str = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_icon_2: builtins.int = ...,
        cover_right_text: builtins.str = ...,
        cover_right_icon: builtins.int = ...,
        cover_right_background_color: builtins.str = ...,
        badge: builtins.str = ...,
        rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base", "rcmd_reason_style", b"rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "base", b"base", "cover_left_icon_1", b"cover_left_icon_1", "cover_left_icon_2", b"cover_left_icon_2", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_right_background_color", b"cover_right_background_color", "cover_right_icon", b"cover_right_icon", "cover_right_text", b"cover_right_text", "left_cover", b"left_cover", "rcmd_reason_style", b"rcmd_reason_style", "right_cover_1", b"right_cover_1", "right_cover_2", b"right_cover_2"]) -> None: ...

global___ThreePicV3 = ThreePicV3

@typing_extensions.final
class OnePicV3(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_ICON_FIELD_NUMBER: builtins.int
    COVER_RIGHT_BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    cover_left_text_1: builtins.str
    """"""
    cover_left_icon_1: builtins.int
    """"""
    cover_right_text: builtins.str
    """"""
    cover_right_icon: builtins.int
    """"""
    cover_right_background_color: builtins.str
    """"""
    badge: builtins.str
    """"""
    @property
    def rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_right_text: builtins.str = ...,
        cover_right_icon: builtins.int = ...,
        cover_right_background_color: builtins.str = ...,
        badge: builtins.str = ...,
        rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base", "rcmd_reason_style", b"rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "base", b"base", "cover_left_icon_1", b"cover_left_icon_1", "cover_left_text_1", b"cover_left_text_1", "cover_right_background_color", b"cover_right_background_color", "cover_right_icon", b"cover_right_icon", "cover_right_text", b"cover_right_text", "rcmd_reason_style", b"rcmd_reason_style"]) -> None: ...

global___OnePicV3 = OnePicV3

@typing_extensions.final
class SmallCoverV7(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "desc", b"desc"]) -> None: ...

global___SmallCoverV7 = SmallCoverV7

@typing_extensions.final
class SmallCoverV9(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_2_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_ICON_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    UP_FIELD_NUMBER: builtins.int
    LEFT_COVER_BADGE_STYLE_FIELD_NUMBER: builtins.int
    LEFT_BOTTOM_RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    cover_left_text_1: builtins.str
    """"""
    cover_left_icon_1: builtins.int
    """"""
    cover_left_text_2: builtins.str
    """"""
    cover_left_icon_2: builtins.int
    """"""
    cover_right_text: builtins.str
    """"""
    cover_right_icon: builtins.int
    """"""
    can_play: builtins.int
    """"""
    @property
    def rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    @property
    def up(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Up:
        """"""
    @property
    def left_cover_badge_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    @property
    def left_bottom_rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_icon_2: builtins.int = ...,
        cover_right_text: builtins.str = ...,
        cover_right_icon: builtins.int = ...,
        can_play: builtins.int = ...,
        rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        up: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Up | None = ...,
        left_cover_badge_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        left_bottom_rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base", "left_bottom_rcmd_reason_style", b"left_bottom_rcmd_reason_style", "left_cover_badge_style", b"left_cover_badge_style", "rcmd_reason_style", b"rcmd_reason_style", "up", b"up"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "can_play", b"can_play", "cover_left_icon_1", b"cover_left_icon_1", "cover_left_icon_2", b"cover_left_icon_2", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_right_icon", b"cover_right_icon", "cover_right_text", b"cover_right_text", "left_bottom_rcmd_reason_style", b"left_bottom_rcmd_reason_style", "left_cover_badge_style", b"left_cover_badge_style", "rcmd_reason_style", b"rcmd_reason_style", "up", b"up"]) -> None: ...

global___SmallCoverV9 = SmallCoverV9

@typing_extensions.final
class SmallCoverConvergeV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_2_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TOP_TEXT_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_V2_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    cover_left_text_1: builtins.str
    """"""
    cover_left_icon_1: builtins.int
    """"""
    cover_left_text_2: builtins.str
    """"""
    cover_left_icon_2: builtins.int
    """"""
    cover_right_text: builtins.str
    """"""
    cover_right_top_text: builtins.str
    """"""
    @property
    def rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    @property
    def rcmd_reason_style_v2(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_icon_2: builtins.int = ...,
        cover_right_text: builtins.str = ...,
        cover_right_top_text: builtins.str = ...,
        rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        rcmd_reason_style_v2: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base", "rcmd_reason_style", b"rcmd_reason_style", "rcmd_reason_style_v2", b"rcmd_reason_style_v2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "cover_left_icon_1", b"cover_left_icon_1", "cover_left_icon_2", b"cover_left_icon_2", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_right_text", b"cover_right_text", "cover_right_top_text", b"cover_right_top_text", "rcmd_reason_style", b"rcmd_reason_style", "rcmd_reason_style_v2", b"rcmd_reason_style_v2"]) -> None: ...

global___SmallCoverConvergeV2 = SmallCoverConvergeV2

@typing_extensions.final
class SmallChannelSpecial(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    BG_COVER_FIELD_NUMBER: builtins.int
    DESC_1_FIELD_NUMBER: builtins.int
    DESC_2_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_2_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    bg_cover: builtins.str
    """"""
    desc_1: builtins.str
    """"""
    desc_2: builtins.str
    """"""
    badge: builtins.str
    """"""
    @property
    def rcmd_reason_style_2(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        bg_cover: builtins.str = ...,
        desc_1: builtins.str = ...,
        desc_2: builtins.str = ...,
        badge: builtins.str = ...,
        rcmd_reason_style_2: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base", "rcmd_reason_style_2", b"rcmd_reason_style_2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "base", b"base", "bg_cover", b"bg_cover", "desc_1", b"desc_1", "desc_2", b"desc_2", "rcmd_reason_style_2", b"rcmd_reason_style_2"]) -> None: ...

global___SmallChannelSpecial = SmallChannelSpecial



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/community/service/govern/v1/govern.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1bilibili/community/service/govern/v1/govern.proto\x12$bilibili.community.service.govern.v1\x1a\x1bgoogle/protobuf/empty.proto\"\xce\x01\n\x0cQoeReportReq\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05scene\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0e\n\x06\x63\x61ncel\x18\x04 \x01(\x08\x12\x15\n\rbusiness_type\x18\x05 \x01(\t\x12\x0b\n\x03oid\x18\x06 \x01(\x03\x12J\n\x0cscore_result\x18\x07 \x01(\x0b\x32\x34.bilibili.community.service.govern.v1.QoeScoreResult\x12\x15\n\rbusiness_data\x18\x08 \x01(\t\"\x1f\n\x0eQoeScoreResult\x12\r\n\x05score\x18\x01 \x01(\x02\x32^\n\x03Qoe\x12W\n\tQoeReport\x12\x32.bilibili.community.service.govern.v1.QoeReportReq\x1a\x16.google.protobuf.Emptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.community.service.govern.v1.govern_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_QOEREPORTREQ']._serialized_start=121
  _globals['_QOEREPORTREQ']._serialized_end=327
  _globals['_QOESCORERESULT']._serialized_start=329
  _globals['_QOESCORERESULT']._serialized_end=360
  _globals['_QOE']._serialized_start=362
  _globals['_QOE']._serialized_end=456
# @@protoc_insertion_point(module_scope)
